Crate stormbird

Crate stormbird 

Stormbird

Stormbird is a library that unifies the implementation of two similar but different methods: the discrete lifting line method and the actuator line method. This crate contains the core functionality written in Rust. Other libraries, such as the pystormbird crate, contain interfaces to this library. See the Stormbird GitHub page for more information.

Modules

actuator_line
Implementation of actuator line functionality.
common_utils
Collection of structs used for multiple simulations methods, i.e., useful for both lifting line and actuator line methods.
controller
Implementations of a controller for wind propulsion devices intended to be used together with the simulation models in the library.
elliptic_wing_theory
Implementation of some of the theoretical functions from elliptic wing theory, based on the classical lifting line theory.
empirical_models
Extra force models that can be used together with the sail models
error
An implementation of a common error type that is used throughout the library.
io_utils
Input and output utilities for the library, such as writing text to files or managing folders.
lifting_line
Implementation of lifting line functionality.
line_force_model
Functionality for representing wings as “line objects”, without any assumptions about how lift-induced velocities are estimated. In other words, this part is common for all methods available in the library, and therefore the foundation of all simulations.
section_models
Models of two dimensional lift and drag on wing sections, such as foil profiles and rotating cylinders.
wind