get_appservice_deployment_objects

Function get_appservice_deployment_objects 

pub async fn get_appservice_deployment_objects(
    client: &Client,
    namespace: &str,
    coredb_name: &str,
) -> Result<Vec<Deployment>, Error>
Retrieves all AppService component Deployments in the namespace

This function should return all available deployments with an AppService label and return the actual Deployment struct for each as a vector. This allows us to use the full current state of the deployment rather than simply the name.