pub struct ClusterBackupBarmanObjectStoreWal {
pub compression: Option<ClusterBackupBarmanObjectStoreWalCompression>,
pub encryption: Option<ClusterBackupBarmanObjectStoreWalEncryption>,
pub max_parallel: Option<i64>,
}Expand description
The configuration for the backup of the WAL stream. When not defined, WAL files will be stored uncompressed and may be unencrypted in the object store, according to the bucket default policy.
Fields
compression: Option<ClusterBackupBarmanObjectStoreWalCompression>Compress a WAL file before sending it to the object store. Available options are empty string (no compression, default), gzip, bzip2 or snappy.
encryption: Option<ClusterBackupBarmanObjectStoreWalEncryption>Whenever to force the encryption of files (if the bucket is not already configured for that). Allowed options are empty string (use the bucket policy, default), AES256 and aws:kms
max_parallel: Option<i64>Number of WAL files to be either archived in parallel (when the PostgreSQL instance is archiving to a backup object store) or restored in parallel (when a PostgreSQL standby is fetching WAL files from a recovery object store). If not specified, WAL files will be processed one at a time. It accepts a positive integer as a value - with 1 being the minimum accepted value.