ClusterBootstrapRecoveryRecoveryTarget

Struct ClusterBootstrapRecoveryRecoveryTarget 

pub struct ClusterBootstrapRecoveryRecoveryTarget {
    pub backup_id: Option<String>,
    pub exclusive: Option<bool>,
    pub target_immediate: Option<bool>,
    pub target_lsn: Option<String>,
    pub target_name: Option<String>,
    pub target_tli: Option<String>,
    pub target_time: Option<String>,
    pub target_xid: Option<String>,
}
By default, the recovery process applies all the available WAL files in the archive (full recovery). However, you can also end the recovery as soon as a consistent state is reached or recover to a point-in-time (PITR) by specifying a RecoveryTarget object, as expected by PostgreSQL (i.e., timestamp, transaction Id, LSN, …). More info: https://www.postgresql.org/docs/current/runtime-config-wal.html#RUNTIME-CONFIG-WAL-RECOVERY-TARGET

Fields

backup_id: Option<String>

The ID of the backup from which to start the recovery process. If empty (default) the operator will automatically detect the backup based on targetTime or targetLSN if specified. Otherwise use the latest available backup in chronological order.

exclusive: Option<bool>

Set the target to be exclusive. If omitted, defaults to false, so that in Postgres, recovery_target_inclusive will be true

target_immediate: Option<bool>

End recovery as soon as a consistent state is reached

target_lsn: Option<String>

The target LSN (Log Sequence Number)

target_name: Option<String>

The target name (to be previously created with pg_create_restore_point)

target_tli: Option<String>

The target timeline (“latest” or a positive integer)

target_time: Option<String>

The target time as a timestamp in the RFC3339 standard

target_xid: Option<String>

The target transaction ID