pub struct ClusterEnvValueFromFieldRef {
pub api_version: Option<String>,
pub field_path: String,
}Expand description
Selects a field of the pod: supports metadata.name, metadata.namespace, metadata.labels['<KEY>'], metadata.annotations['<KEY>'], spec.nodeName, spec.serviceAccountName, status.hostIP, status.podIP, status.podIPs.
Fields
api_version: Option<String>Version of the schema the FieldPath is written in terms of, defaults to “v1”.
field_path: StringPath of the field to select in the specified API version.