pub struct ClusterExternalClustersBarmanObjectStore {
pub azure_credentials: Option<ClusterExternalClustersBarmanObjectStoreAzureCredentials>,
pub data: Option<ClusterExternalClustersBarmanObjectStoreData>,
pub destination_path: String,
pub endpoint_ca: Option<ClusterExternalClustersBarmanObjectStoreEndpointCa>,
pub endpoint_url: Option<String>,
pub google_credentials: Option<ClusterExternalClustersBarmanObjectStoreGoogleCredentials>,
pub history_tags: Option<BTreeMap<String, String>>,
pub s3_credentials: Option<ClusterExternalClustersBarmanObjectStoreS3Credentials>,
pub server_name: Option<String>,
pub tags: Option<BTreeMap<String, String>>,
pub wal: Option<ClusterExternalClustersBarmanObjectStoreWal>,
}Expand description
The configuration for the barman-cloud tool suite
Fields
azure_credentials: Option<ClusterExternalClustersBarmanObjectStoreAzureCredentials>The credentials to use to upload data to Azure Blob Storage
data: Option<ClusterExternalClustersBarmanObjectStoreData>The configuration to be used to backup the data files When not defined, base backups files will be stored uncompressed and may be unencrypted in the object store, according to the bucket default policy.
destination_path: StringThe path where to store the backup (i.e. s3://bucket/path/to/folder) this path, with different destination folders, will be used for WALs and for data
endpoint_ca: Option<ClusterExternalClustersBarmanObjectStoreEndpointCa>EndpointCA store the CA bundle of the barman endpoint. Useful when using self-signed certificates to avoid errors with certificate issuer and barman-cloud-wal-archive
endpoint_url: Option<String>Endpoint to be used to upload data to the cloud, overriding the automatic endpoint discovery
google_credentials: Option<ClusterExternalClustersBarmanObjectStoreGoogleCredentials>The credentials to use to upload data to Google Cloud Storage
HistoryTags is a list of key value pairs that will be passed to the Barman –history-tags option.
s3_credentials: Option<ClusterExternalClustersBarmanObjectStoreS3Credentials>The credentials to use to upload data to S3
server_name: Option<String>The server name on S3, the cluster name is used if this parameter is omitted
Tags is a list of key value pairs that will be passed to the Barman –tags option.
wal: Option<ClusterExternalClustersBarmanObjectStoreWal>The configuration for the backup of the WAL stream. When not defined, WAL files will be stored uncompressed and may be unencrypted in the object store, according to the bucket default policy.