pub struct ClusterMonitoring {
pub custom_queries_config_map: Option<Vec<ClusterMonitoringCustomQueriesConfigMap>>,
pub custom_queries_secret: Option<Vec<ClusterMonitoringCustomQueriesSecret>>,
pub disable_default_queries: Option<bool>,
pub enable_pod_monitor: Option<bool>,
pub pod_monitor_metric_relabelings: Option<Vec<ClusterMonitoringPodMonitorMetricRelabelings>>,
pub pod_monitor_relabelings: Option<Vec<ClusterMonitoringPodMonitorRelabelings>>,
}Expand description
The configuration of the monitoring infrastructure of this cluster
Fields
custom_queries_config_map: Option<Vec<ClusterMonitoringCustomQueriesConfigMap>>The list of config maps containing the custom queries
custom_queries_secret: Option<Vec<ClusterMonitoringCustomQueriesSecret>>The list of secrets containing the custom queries
disable_default_queries: Option<bool>Whether the default queries should be injected. Set it to true if you don’t want to inject default queries into the cluster. Default: false.
enable_pod_monitor: Option<bool>Enable or disable the PodMonitor
pod_monitor_metric_relabelings: Option<Vec<ClusterMonitoringPodMonitorMetricRelabelings>>The list of metric relabelings for the PodMonitor. Applied to samples before ingestion.
pod_monitor_relabelings: Option<Vec<ClusterMonitoringPodMonitorRelabelings>>The list of relabelings for the PodMonitor. Applied to samples before scraping.