pub struct ClusterMonitoringPodMonitorMetricRelabelings {
pub action: Option<ClusterMonitoringPodMonitorMetricRelabelingsAction>,
pub modulus: Option<i64>,
pub regex: Option<String>,
pub replacement: Option<String>,
pub separator: Option<String>,
pub source_labels: Option<Vec<String>>,
pub target_label: Option<String>,
}Expand description
RelabelConfig allows dynamic rewriting of the label set for targets, alerts, scraped samples and remote write samples. More info: https://prometheus.io/docs/prometheus/latest/configuration/configuration/#relabel_config
Fields
action: Option<ClusterMonitoringPodMonitorMetricRelabelingsAction>Action to perform based on the regex matching.
Uppercase and Lowercase actions require Prometheus >= v2.36.0. DropEqual and KeepEqual actions require Prometheus >= v2.41.0.
Default: “Replace”
modulus: Option<i64>Modulus to take of the hash of the source label values.
Only applicable when the action is HashMod.
regex: Option<String>Regular expression against which the extracted value is matched.
replacement: Option<String>Replacement value against which a Replace action is performed if the regular expression matches. Regex capture groups are available.
separator: Option<String>Separator is the string between concatenated SourceLabels.
source_labels: Option<Vec<String>>The source labels select values from existing labels. Their content is concatenated using the configured Separator and matched against the configured regular expression.
target_label: Option<String>Label to which the resulting string is written in a replacement.
It is mandatory for Replace, HashMod, Lowercase, Uppercase, KeepEqual and DropEqual actions.
Regex capture groups are available.