pub struct ClusterProjectedVolumeTemplateSourcesConfigMap {
pub items: Option<Vec<ClusterProjectedVolumeTemplateSourcesConfigMapItems>>,
pub name: Option<String>,
pub optional: Option<bool>,
}Expand description
configMap information about the configMap data to project
Fields
items: Option<Vec<ClusterProjectedVolumeTemplateSourcesConfigMapItems>>items if unspecified, each key-value pair in the Data field of the referenced ConfigMap will be projected into the volume as a file whose name is the key and content is the value. If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the ConfigMap, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the ‘..’ path or start with ‘..’.
name: Option<String>Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
optional: Option<bool>optional specify whether the ConfigMap or its keys must be defined