pub struct ClusterReplica {
pub enabled: bool,
pub source: String,
}Expand description
Replica cluster configuration
Fields
enabled: boolIf replica mode is enabled, this cluster will be a replica of an existing cluster. Replica cluster can be created from a recovery object store or via streaming through pg_basebackup. Refer to the Replica clusters page of the documentation for more information.
source: StringThe name of the external cluster which is the replication origin