pub struct PoolerTemplateSpecAffinity {
pub node_affinity: Option<PoolerTemplateSpecAffinityNodeAffinity>,
pub pod_affinity: Option<PoolerTemplateSpecAffinityPodAffinity>,
pub pod_anti_affinity: Option<PoolerTemplateSpecAffinityPodAntiAffinity>,
}Expand description
If specified, the pod’s scheduling constraints
Fields
node_affinity: Option<PoolerTemplateSpecAffinityNodeAffinity>Describes node affinity scheduling rules for the pod.
pod_affinity: Option<PoolerTemplateSpecAffinityPodAffinity>Describes pod affinity scheduling rules (e.g. co-locate this pod in the same node, zone, etc. as some other pod(s)).
pod_anti_affinity: Option<PoolerTemplateSpecAffinityPodAntiAffinity>Describes pod anti-affinity scheduling rules (e.g. avoid putting this pod in the same node, zone, etc. as some other pod(s)).