PoolerTemplateSpecContainersLifecyclePostStart

Struct PoolerTemplateSpecContainersLifecyclePostStart 

pub struct PoolerTemplateSpecContainersLifecyclePostStart {
    pub exec: Option<PoolerTemplateSpecContainersLifecyclePostStartExec>,
    pub http_get: Option<PoolerTemplateSpecContainersLifecyclePostStartHttpGet>,
    pub tcp_socket: Option<PoolerTemplateSpecContainersLifecyclePostStartTcpSocket>,
}
PostStart is called immediately after a container is created. If the handler fails, the container is terminated and restarted according to its restart policy. Other management of the container blocks until the hook completes. More info: https://kubernetes.io/docs/concepts/containers/container-lifecycle-hooks/#container-hooks

Fields

exec: Option<PoolerTemplateSpecContainersLifecyclePostStartExec>

Exec specifies the action to take.

http_get: Option<PoolerTemplateSpecContainersLifecyclePostStartHttpGet>

HTTPGet specifies the http request to perform.

tcp_socket: Option<PoolerTemplateSpecContainersLifecyclePostStartTcpSocket>

Deprecated. TCPSocket is NOT supported as a LifecycleHandler and kept for the backward compatibility. There are no validation of this field and lifecycle hooks will fail in runtime when tcp handler is specified.