pub struct PoolerTemplateSpecContainersPorts {
pub container_port: i32,
pub host_ip: Option<String>,
pub host_port: Option<i32>,
pub name: Option<String>,
pub protocol: Option<String>,
}Expand description
ContainerPort represents a network port in a single container.
Fields
container_port: i32Number of port to expose on the pod’s IP address. This must be a valid port number, 0 < x < 65536.
host_ip: Option<String>What host IP to bind the external port to.
host_port: Option<i32>Number of port to expose on the host. If specified, this must be a valid port number, 0 < x < 65536. If HostNetwork is specified, this must match ContainerPort. Most containers do not need this.
name: Option<String>If specified, this must be an IANA_SVC_NAME and unique within the pod. Each named port in a pod must have a unique name. Name for the port that can be referred to by services.
protocol: Option<String>Protocol for port. Must be UDP, TCP, or SCTP. Defaults to “TCP”.