pub struct PoolerTemplateSpecEphemeralContainersSecurityContext {
pub allow_privilege_escalation: Option<bool>,
pub capabilities: Option<PoolerTemplateSpecEphemeralContainersSecurityContextCapabilities>,
pub privileged: Option<bool>,
pub proc_mount: Option<String>,
pub read_only_root_filesystem: Option<bool>,
pub run_as_group: Option<i64>,
pub run_as_non_root: Option<bool>,
pub run_as_user: Option<i64>,
pub se_linux_options: Option<PoolerTemplateSpecEphemeralContainersSecurityContextSeLinuxOptions>,
pub seccomp_profile: Option<PoolerTemplateSpecEphemeralContainersSecurityContextSeccompProfile>,
pub windows_options: Option<PoolerTemplateSpecEphemeralContainersSecurityContextWindowsOptions>,
}Expand description
Optional: SecurityContext defines the security options the ephemeral container should be run with. If set, the fields of SecurityContext override the equivalent fields of PodSecurityContext.
Fields
allow_privilege_escalation: Option<bool>AllowPrivilegeEscalation controls whether a process can gain more privileges than its parent process. This bool directly controls if the no_new_privs flag will be set on the container process. AllowPrivilegeEscalation is true always when the container is: 1) run as Privileged 2) has CAP_SYS_ADMIN Note that this field cannot be set when spec.os.name is windows.
capabilities: Option<PoolerTemplateSpecEphemeralContainersSecurityContextCapabilities>The capabilities to add/drop when running containers. Defaults to the default set of capabilities granted by the container runtime. Note that this field cannot be set when spec.os.name is windows.
privileged: Option<bool>Run container in privileged mode. Processes in privileged containers are essentially equivalent to root on the host. Defaults to false. Note that this field cannot be set when spec.os.name is windows.
proc_mount: Option<String>procMount denotes the type of proc mount to use for the containers. The default is DefaultProcMount which uses the container runtime defaults for readonly paths and masked paths. This requires the ProcMountType feature flag to be enabled. Note that this field cannot be set when spec.os.name is windows.
read_only_root_filesystem: Option<bool>Whether this container has a read-only root filesystem. Default is false. Note that this field cannot be set when spec.os.name is windows.
run_as_group: Option<i64>The GID to run the entrypoint of the container process. Uses runtime default if unset. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence. Note that this field cannot be set when spec.os.name is windows.
run_as_non_root: Option<bool>Indicates that the container must run as a non-root user. If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
run_as_user: Option<i64>The UID to run the entrypoint of the container process. Defaults to user specified in image metadata if unspecified. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence. Note that this field cannot be set when spec.os.name is windows.
se_linux_options: Option<PoolerTemplateSpecEphemeralContainersSecurityContextSeLinuxOptions>The SELinux context to be applied to the container. If unspecified, the container runtime will allocate a random SELinux context for each container. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence. Note that this field cannot be set when spec.os.name is windows.
seccomp_profile: Option<PoolerTemplateSpecEphemeralContainersSecurityContextSeccompProfile>The seccomp options to use by this container. If seccomp options are provided at both the pod & container level, the container options override the pod options. Note that this field cannot be set when spec.os.name is windows.
windows_options: Option<PoolerTemplateSpecEphemeralContainersSecurityContextWindowsOptions>The Windows specific settings applied to all containers. If unspecified, the options from the PodSecurityContext will be used. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence. Note that this field cannot be set when spec.os.name is linux.