pub struct PoolerTemplateSpecInitContainersEnv {
pub name: String,
pub value: Option<String>,
pub value_from: Option<PoolerTemplateSpecInitContainersEnvValueFrom>,
}Expand description
EnvVar represents an environment variable present in a Container.
Fields
name: StringName of the environment variable. Must be a C_IDENTIFIER.
value: Option<String>Variable references $(VAR_NAME) are expanded using the previously defined environment variables in the container and any service environment variables. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. “$$(VAR_NAME)” will produce the string literal “$(VAR_NAME)”. Escaped references will never be expanded, regardless of whether the variable exists or not. Defaults to “”.
value_from: Option<PoolerTemplateSpecInitContainersEnvValueFrom>Source for the environment variable’s value. Cannot be used if value is not empty.