Struct controller::cloudnativepg::poolers::PoolerTemplateSpecInitContainersLifecyclePreStopHttpGetHttpHeaders
source · pub struct PoolerTemplateSpecInitContainersLifecyclePreStopHttpGetHttpHeaders {
pub name: String,
pub value: String,
}Expand description
HTTPHeader describes a custom header to be used in HTTP probes
Fields
name: StringThe header field name. This will be canonicalized upon output, so case-variant names will be understood as the same header.
value: StringThe header field value