pub struct PoolerTemplateSpecInitContainersLivenessProbeGrpc {
pub port: i32,
pub service: Option<String>,
}Expand description
GRPC specifies an action involving a GRPC port.
Fields
port: i32Port number of the gRPC service. Number must be in the range 1 to 65535.
service: Option<String>Service is the name of the service to place in the gRPC HealthCheckRequest (see https://github.com/grpc/grpc/blob/master/doc/health-checking.md). If this is not specified, the default behavior is defined by gRPC.