pub struct PoolerTemplateSpecInitContainersResources {
    pub claims: Option<Vec<PoolerTemplateSpecInitContainersResourcesClaims>>,
    pub limits: Option<BTreeMap<String, IntOrString>>,
    pub requests: Option<BTreeMap<String, IntOrString>>,
}
Compute Resources required by this container. Cannot be updated. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/

Fields

claims: Option<Vec<PoolerTemplateSpecInitContainersResourcesClaims>>

Claims lists the names of resources, defined in spec.resourceClaims, that are used by this container. This is an alpha field and requires enabling the DynamicResourceAllocation feature gate. This field is immutable. It can only be set for containers.

limits: Option<BTreeMap<String, IntOrString>>

Limits describes the maximum amount of compute resources allowed. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/

requests: Option<BTreeMap<String, IntOrString>>

Requests describes the minimum amount of compute resources required. If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. Requests cannot exceed Limits. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/