pub struct PoolerTemplateSpecInitContainersVolumeDevices {
pub device_path: String,
pub name: String,
}Expand description
volumeDevice describes a mapping of a raw block device within a container.
Fields
device_path: StringdevicePath is the path inside of the container that the device will be mapped to.
name: Stringname must match the name of a persistentVolumeClaim in the pod