pub struct PoolerTemplateSpecInitContainersVolumeMounts {
pub mount_path: String,
pub mount_propagation: Option<String>,
pub name: String,
pub read_only: Option<bool>,
pub sub_path: Option<String>,
pub sub_path_expr: Option<String>,
}Expand description
VolumeMount describes a mounting of a Volume within a container.
Fields
mount_path: StringPath within the container at which the volume should be mounted. Must not contain ‘:’.
mount_propagation: Option<String>mountPropagation determines how mounts are propagated from the host to container and the other way around. When not set, MountPropagationNone is used. This field is beta in 1.10.
name: StringThis must match the Name of a Volume.
read_only: Option<bool>Mounted read-only if true, read-write otherwise (false or unspecified). Defaults to false.
sub_path: Option<String>Path within the volume from which the container’s volume should be mounted. Defaults to “” (volume’s root).
sub_path_expr: Option<String>Expanded path within the volume from which the container’s volume should be mounted. Behaves similarly to SubPath but environment variable references $(VAR_NAME) are expanded using the container’s environment. Defaults to “” (volume’s root). SubPathExpr and SubPath are mutually exclusive.