pub struct PoolerTemplateSpecVolumesAzureDisk {
pub caching_mode: Option<String>,
pub disk_name: String,
pub disk_uri: String,
pub fs_type: Option<String>,
pub kind: Option<String>,
pub read_only: Option<bool>,
}Expand description
azureDisk represents an Azure Data Disk mount on the host and bind mount to the pod.
Fields
caching_mode: Option<String>cachingMode is the Host Caching mode: None, Read Only, Read Write.
disk_name: StringdiskName is the Name of the data disk in the blob storage
disk_uri: StringdiskURI is the URI of data disk in the blob storage
fs_type: Option<String>fsType is Filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. “ext4”, “xfs”, “ntfs”. Implicitly inferred to be “ext4” if unspecified.
kind: Option<String>kind expected values are Shared: multiple blob disks per storage account Dedicated: single blob disk per storage account Managed: azure managed data disk (only in managed availability set). defaults to shared
read_only: Option<bool>readOnly Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.