pub struct PoolerTemplateSpecVolumesPhotonPersistentDisk {
pub fs_type: Option<String>,
pub pd_id: String,
}Expand description
photonPersistentDisk represents a PhotonController persistent disk attached and mounted on kubelets host machine
Fields
fs_type: Option<String>fsType is the filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. “ext4”, “xfs”, “ntfs”. Implicitly inferred to be “ext4” if unspecified.
pd_id: StringpdID is the ID that identifies Photon Controller persistent disk