Module controller::extensions::database_queries
source · Structs
Constants
Functions
- list databases then get all extensions from each database
- Returns Ok if the given database is running (i.e. not restarting)
- List all configuration parameters
- returns all the databases in an instance
- lists all extensions in a single database
- Parse the output of
SHOW ALLto get the parameter and its value. Return Vec - Handles create/drop an extension location On failure, returns an error message