pub struct ClusterStatus {Show 40 fields
pub azure_pvc_update_enabled: Option<bool>,
pub certificates: Option<ClusterStatusCertificates>,
pub cloud_native_pg_commit_hash: Option<String>,
pub cloud_native_pg_operator_hash: Option<String>,
pub conditions: Option<Vec<ClusterStatusConditions>>,
pub config_map_resource_version: Option<ClusterStatusConfigMapResourceVersion>,
pub current_primary: Option<String>,
pub current_primary_failing_since_timestamp: Option<String>,
pub current_primary_timestamp: Option<String>,
pub dangling_pvc: Option<Vec<String>>,
pub first_recoverability_point: Option<String>,
pub first_recoverability_point_by_method: Option<BTreeMap<String, String>>,
pub healthy_pvc: Option<Vec<String>>,
pub initializing_pvc: Option<Vec<String>>,
pub instance_names: Option<Vec<String>>,
pub instances: Option<i64>,
pub instances_reported_state: Option<BTreeMap<String, ClusterStatusInstancesReportedState>>,
pub instances_status: Option<BTreeMap<String, Vec<String>>>,
pub job_count: Option<i32>,
pub last_failed_backup: Option<String>,
pub last_successful_backup: Option<String>,
pub last_successful_backup_by_method: Option<BTreeMap<String, String>>,
pub latest_generated_node: Option<i64>,
pub managed_roles_status: Option<ClusterStatusManagedRolesStatus>,
pub online_update_enabled: Option<bool>,
pub phase: Option<String>,
pub phase_reason: Option<String>,
pub pooler_integrations: Option<ClusterStatusPoolerIntegrations>,
pub pvc_count: Option<i32>,
pub read_service: Option<String>,
pub ready_instances: Option<i64>,
pub resizing_pvc: Option<Vec<String>>,
pub secrets_resource_version: Option<ClusterStatusSecretsResourceVersion>,
pub tablespaces_status: Option<Vec<ClusterStatusTablespacesStatus>>,
pub target_primary: Option<String>,
pub target_primary_timestamp: Option<String>,
pub timeline_id: Option<i64>,
pub topology: Option<ClusterStatusTopology>,
pub unusable_pvc: Option<Vec<String>>,
pub write_service: Option<String>,
}Expand description
Most recently observed status of the cluster. This data may not be up to date. Populated by the system. Read-only. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
Fields
azure_pvc_update_enabled: Option<bool>AzurePVCUpdateEnabled shows if the PVC online upgrade is enabled for this cluster
certificates: Option<ClusterStatusCertificates>The configuration for the CA and related certificates, initialized with defaults.
cloud_native_pg_commit_hash: Option<String>The commit hash number of which this operator running
cloud_native_pg_operator_hash: Option<String>The hash of the binary of the operator
conditions: Option<Vec<ClusterStatusConditions>>Conditions for cluster object
config_map_resource_version: Option<ClusterStatusConfigMapResourceVersion>The list of resource versions of the configmaps, managed by the operator. Every change here is done in the interest of the instance manager, which will refresh the configmap data
current_primary: Option<String>Current primary instance
current_primary_failing_since_timestamp: Option<String>The timestamp when the primary was detected to be unhealthy This field is reported when .spec.failoverDelay is populated or during online upgrades
current_primary_timestamp: Option<String>The timestamp when the last actual promotion to primary has occurred
dangling_pvc: Option<Vec<String>>List of all the PVCs created by this cluster and still available which are not attached to a Pod
first_recoverability_point: Option<String>The first recoverability point, stored as a date in RFC3339 format. This field is calculated from the content of FirstRecoverabilityPointByMethod
first_recoverability_point_by_method: Option<BTreeMap<String, String>>The first recoverability point, stored as a date in RFC3339 format, per backup method type
healthy_pvc: Option<Vec<String>>List of all the PVCs not dangling nor initializing
initializing_pvc: Option<Vec<String>>List of all the PVCs that are being initialized by this cluster
instance_names: Option<Vec<String>>List of instance names in the cluster
instances: Option<i64>The total number of PVC Groups detected in the cluster. It may differ from the number of existing instance pods.
instances_reported_state: Option<BTreeMap<String, ClusterStatusInstancesReportedState>>The reported state of the instances during the last reconciliation loop
instances_status: Option<BTreeMap<String, Vec<String>>>InstancesStatus indicates in which status the instances are
job_count: Option<i32>How many Jobs have been created by this cluster
last_failed_backup: Option<String>Stored as a date in RFC3339 format
last_successful_backup: Option<String>Last successful backup, stored as a date in RFC3339 format This field is calculated from the content of LastSuccessfulBackupByMethod
last_successful_backup_by_method: Option<BTreeMap<String, String>>Last successful backup, stored as a date in RFC3339 format, per backup method type
latest_generated_node: Option<i64>ID of the latest generated node (used to avoid node name clashing)
managed_roles_status: Option<ClusterStatusManagedRolesStatus>ManagedRolesStatus reports the state of the managed roles in the cluster
online_update_enabled: Option<bool>OnlineUpdateEnabled shows if the online upgrade is enabled inside the cluster
phase: Option<String>Current phase of the cluster
phase_reason: Option<String>Reason for the current phase
pooler_integrations: Option<ClusterStatusPoolerIntegrations>The integration needed by poolers referencing the cluster
pvc_count: Option<i32>How many PVCs have been created by this cluster
read_service: Option<String>Current list of read pods
ready_instances: Option<i64>The total number of ready instances in the cluster. It is equal to the number of ready instance pods.
resizing_pvc: Option<Vec<String>>List of all the PVCs that have ResizingPVC condition.
secrets_resource_version: Option<ClusterStatusSecretsResourceVersion>The list of resource versions of the secrets managed by the operator. Every change here is done in the interest of the instance manager, which will refresh the secret data
tablespaces_status: Option<Vec<ClusterStatusTablespacesStatus>>TablespacesStatus reports the state of the declarative tablespaces in the cluster
target_primary: Option<String>Target primary instance, this is different from the previous one during a switchover or a failover
target_primary_timestamp: Option<String>The timestamp when the last request for a new primary has occurred
timeline_id: Option<i64>The timeline of the Postgres cluster
topology: Option<ClusterStatusTopology>Instances topology.
unusable_pvc: Option<Vec<String>>List of all the PVCs that are unusable because another PVC is missing
write_service: Option<String>Current write pod