pub struct ClusterTablespacesStorage {
pub pvc_template: Option<ClusterTablespacesStoragePvcTemplate>,
pub resize_in_use_volumes: Option<bool>,
pub size: Option<String>,
pub storage_class: Option<String>,
}Expand description
The storage configuration for the tablespace
Fields
pvc_template: Option<ClusterTablespacesStoragePvcTemplate>Template to be used to generate the Persistent Volume Claim
resize_in_use_volumes: Option<bool>Resize existent PVCs, defaults to true
size: Option<String>Size of the storage. Required if not already specified in the PVC template. Changes to this field are automatically reapplied to the created PVCs. Size cannot be decreased.
storage_class: Option<String>StorageClass to use for PVCs. Applied after evaluating the PVC template, if available. If not specified, the generated PVCs will use the default storage class