pub struct PoolerTemplateSpecVolumesStorageos {
pub fs_type: Option<String>,
pub read_only: Option<bool>,
pub secret_ref: Option<PoolerTemplateSpecVolumesStorageosSecretRef>,
pub volume_name: Option<String>,
pub volume_namespace: Option<String>,
}Expand description
storageOS represents a StorageOS volume attached and mounted on Kubernetes nodes.
Fields
fs_type: Option<String>fsType is the filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. “ext4”, “xfs”, “ntfs”. Implicitly inferred to be “ext4” if unspecified.
read_only: Option<bool>readOnly defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.
secret_ref: Option<PoolerTemplateSpecVolumesStorageosSecretRef>secretRef specifies the secret to use for obtaining the StorageOS API credentials. If not specified, default values will be attempted.
volume_name: Option<String>volumeName is the human-readable name of the StorageOS volume. Volume names are only unique within a namespace.
volume_namespace: Option<String>volumeNamespace specifies the scope of the volume within StorageOS. If no namespace is specified then the Pod’s namespace will be used. This allows the Kubernetes name scoping to be mirrored within StorageOS for tighter integration. Set VolumeName to any name to override the default behaviour. Set to “default” if you are not using namespaces within StorageOS. Namespaces that do not pre-exist within StorageOS will be created.