pub enum ListenerType {
Or,
Dir,
Socks,
Trans,
Natd,
Dns,
Control,
ExtOr,
HttpTunnel,
}Expand description
Types of listeners that Tor can have.
These correspond to the different types of connections that Tor handles, each configured via different torrc options.
Example
use stem::controller::ListenerType;
let listener = ListenerType::Socks;
assert_eq!(listener.to_string(), "socks");Variants
Or
Traffic we’re relaying as a member of the network (ORPort)
Dir
Mirroring for tor descriptor content (DirPort)
Socks
Client traffic we’re sending over Tor (SocksPort)
Trans
Transparent proxy handling (TransPort)
Natd
Forwarding for ipfw NATD connections (NatdPort)
Dns
DNS lookups for our traffic (DNSPort)
Control
Controller applications (ControlPort)
ExtOr
Pluggable transport for Extended ORPorts (ExtORPort)
HttpTunnel
HTTP tunneling proxy (HTTPTunnelPort)